#
# spec file for package python-metakernel
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-metakernel
Version:        0.24.4
Release:        bp156.3.2
Summary:        Metakernel for Jupyter
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Calysto/metakernel
Source:         https://files.pythonhosted.org/packages/source/m/metakernel/metakernel-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ipykernel
Requires:       python-ipyparallel
Requires:       python-pexpect >= 4.2
Provides:       python-jupyter_metakernel = %{version}
Obsoletes:      python-jupyter_metakernel < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module ipyparallel}
BuildRequires:  %{python_module pexpect >= 4.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  coreutils-doc
BuildRequires:  man
# /SECTION
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-metakernel = %{version}
%endif
%python_subpackages

%description
A Jupyter/IPython kernel template which includes core magic functions
(including help, command and file path completion, parallel and
distributed processing, downloads, and much more).

%prep
%setup -q -n metakernel-%{version}
touch ~/.bashrc

%build
%python_build

%install
%python_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/metakernel/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest metakernel/tests

%files %{python_files}
%doc CONTRIBUTORS.rst HISTORY.rst README.rst
%license LICENSE.txt
%{python_sitelib}/metakernel
%{python_sitelib}/metakernel-%{version}-py*.egg-info

%changelog
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
* Sun Apr 26 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
- update to version 0.24.4:
  * portalocker and ipyparallel as optional dependencies
  * Remove undefined line in expect stdin
* Thu Mar 12 2020 Hans-Peter Jansen <hpj@urpla.net>
- add coreutils-doc as build dependency, testing calls man sleep
* Fri Dec  6 2019 Todd R <toddrme2178@gmail.com>
- Disable python2 support since dependencies dropped python2
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.24.3
  * Update setup.py
  * Update activity_magic.py
* Thu Aug  8 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Remove unnecessary indirect dependencies
- Remove tests from runtime package
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.24.2
  * Fix TypeError
- Update to 0.24.1
  * delay creating wrapper until we need to execute
- Update to 0.24.0
  * finish transition to pytest
  * Finish updates to stream_handler
  * remove local bash kernel and point to calysto_bash
* Wed May 29 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.23.0
  * Clean up configurability handling and docs
  * fix handling of kernel class
  * export the metakernel app
  * Add settings handling
  * switch to powershell on windows
  * clean up interrupt behavior and error handling
  * clean up stdin handler
  * clean up replwrap prompt handling
  * avoid double printing output
  * add support for cr printing
  * Fix handling metadata in _formatter
  * Define cluster_size and cluster_rank on host kernel
  * kernel.parent can be None in some situations
  * Allow help and info to return mime-type data
  * Adjustment for newer jedi
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
* Wed Mar 21 2018 sebix+novell.com@sebix.at
- Use %%license macro for license.
* Thu Feb 15 2018 toddrme2178@gmail.com
- Update to 0.20.14
  * No changelog
* Mon Nov  6 2017 toddrme2178@gmail.com
- Update to 0.20.12
  * No changelog
* Wed Sep 20 2017 toddrme2178@gmail.com
- Update to 0.20.7
  * No changelog
* Wed Jul 12 2017 toddrme2178@gmail.com
- Initial version
